@@ -1,5 +1,6 @@
 import os
 from django.apps import apps
+from django.conf import settings
 
 
 class CrudMaker(object):
@@ -11,6 +12,8 @@ class CrudMaker(object):
 
         # Get All Django Models
         self.__all_models = [x.__name__ for x in apps.get_app_config(app_name).get_models()]
+        django_settings_module = settings.SETTINGS_MODULE
+        self.__settings_module = django_settings_module.split('.')[0]
         self.__exclude_fields = list(exclude_fields)
         self.__graphql_path = os.path.join(app_name, 'graphql')
         self.__base_path = os.path.join(self.BASE_DIR, 'graphene_crud_maker', 'base')
@@ -20,6 +23,8 @@ class CrudMaker(object):
         self.__create_Api_folder(self.__graphql_path, self.__base_path)
         self.__create_queries(self.__base_path)
         self.__create_mutations(self.__base_path)
+        self.__create_custom_schema(self.__base_path)
+        self.__create_relay_query(self.__base_path)
 
 
     def __create_Api_folder(self, graphql_path, base_path):
@@ -29,10 +34,10 @@ class CrudMaker(object):
             os.makedirs(os.path.join(graphql_path, 'query'))
             os.makedirs(os.path.join(graphql_path, 'mutation'))
 
-        if not os.path.join(graphql_path, '__init__.py'):
+        if not os.path.exists(os.path.join(graphql_path, '__init__.py')):
             with open(os.path.join(graphql_path, f'__init__.py'), 'w') as fw: pass
 
-        if not os.path.join(graphql_path, 'schema.py'):
+        if not os.path.exists(os.path.join(graphql_path, 'schema.py')):
             with open(os.path.join(base_path, f'BaseSchema.txt'), 'r') as fr:
                 ### WRITING NEW schema FILE
                 with open(os.path.join(graphql_path, 'schema.py'), 'w') as fw:
@@ -73,7 +78,7 @@ class CrudMaker(object):
         # Writing __init__.py for queries
         with open(os.path.join(query_path, f'__init__.py'), 'w') as fw:
             fw.write('from graphene import ObjectType \n')
-            fw.write('from Core.utils import CustomNode \n')
+            fw.write(f'from {self.__settings_module}.schema.utils import CustomNode \n')
             fw.write('from graphene_django.filter import DjangoFilterConnectionField \n')
             fw.write('\n')
 
@@ -89,6 +94,36 @@ class CrudMaker(object):
             self.list_class.clear()
             self.list_import.clear()
 
+    def __create_custom_schema(self, base_path):
+        module_path = self.__settings_module
+        
+        if not os.path.exists(os.path.join(module_path, 'schema')):
+            os.makedirs(os.path.join(module_path, 'schema'))
+
+        if not os.path.exists(os.path.join(module_path,'schema', 'schema.py')):
+            with open(os.path.join(base_path, f'CoreSchema.txt'), 'r') as fr:
+                ### WRITING NEW schema FILE
+                with open(os.path.join(module_path,'schema', 'schema.py'), 'w') as fw:
+                    for line in fr.readlines():
+                        if line.__contains__('App_'):
+                            line = line.replace('App_', self.app_name)
+                        fw.write(line)
+
+        
+    def __create_relay_query(self, base_path):
+        module_path = self.__settings_module
+        
+        if not os.path.exists(os.path.join(module_path, 'schema')):
+            os.makedirs(os.path.join(module_path, 'schema'))
+
+        if not os.path.exists(os.path.join(module_path,'schema', 'utils.py')):
+            with open(os.path.join(base_path, f'BaseRelay.txt'), 'r') as fr:
+                ### WRITING NEW utils FILE
+                with open(os.path.join(module_path,'schema', 'utils.py'), 'w') as fw:
+                    for line in fr.readlines():
+                        fw.write(line)
+
+        
 
     def __create_mutations(self, base_path):
         print('You called Create mutations')
@@ -115,15 +150,17 @@ class CrudMaker(object):
                                 line = line.replace('App_', self.app_name)
                             if line.__contains__('pass_fields_'):
                                 takedModel = apps.get_model(self.app_name, model)
-                                # field = [field.name for field in takedModel._meta.get_fields()]
                                 field = sorted((field.name for field in takedModel._meta.concrete_fields))
+                                excludeFields = []
 
-                                # Removing exclude_fields
                                 for item in self.__exclude_fields:
                                     if field.__contains__(item):
-                                        field.remove(item)
+                                        # field.remove(item)
+                                        excludeFields.append(item)
 
-                                line = line.replace('pass_fields_', f'fields = {field}')
+
+                                # line = line.replace('pass_fields_', f'fields = {field}')
+                                line = line.replace('pass_fields_', f'exclude = {excludeFields}')
                             fw.write(line)
 
         # Writing __init__.py for mutations
